from setuptools import setup, find_packages

setup(
    name='atanu_mlkit',
    version='0.0.1',
    packages=find_packages(),
    license='MIT',
    long_description=open('README.md').read(),
    long_description_content_type='text/markdown',
    install_requires=[],
)